==> elo_indexserver_client-0.1.2.tar.gz: elo_indexserver_client-0.1.2/eloclient/models/b_request_ix_service_port_if_checkin_workflow_template.py <==
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.client_info import ClientInfo
    from ..models.lock_z import LockZ
    from ..models.wf_diagram import WFDiagram
    from ..models.wf_diagram_z import WFDiagramZ


T = TypeVar("T", bound="BRequestIXServicePortIFCheckinWorkflowTemplate")


@_attrs_define
class BRequestIXServicePortIFCheckinWorkflowTemplate:
    """
    Attributes:
        ci (Union[Unset, ClientInfo]): Contains the session ticket and the users language and country.
            Each Indexserver interface function, except the
             login, requires a <code>ClientInfo</code> object as parameter with a valid session ticket.
             <p>
             Copyright: Copyright (c) 2004
             </p>
             <p>
             Organisation: ELO Digital Office GmbH
             </p>
        wf (Union[Unset, WFDiagram]): This class represents an active or finished workflow or a workflow template
        wf_z (Union[Unset, WFDiagramZ]): This class encapsulates the constants of the WFDiagramC class.
            <p>
             Copyright: Copyright (c) 2004
             </p>
             <p>
             Organisation: ELO Digital Office GmbH
             </p>
        unlock_z (Union[Unset, LockZ]): This class encapsulates the constants of the LockC class.
            <p>
             Copyright: Copyright (c) 2004
             </p>
             <p>
             Organisation: ELO Digital Office GmbH
             </p>
    """

    ci: Union[Unset, "ClientInfo"] = UNSET
    wf: Union[Unset, "WFDiagram"] = UNSET
    wf_z: Union[Unset, "WFDiagramZ"] = UNSET
    unlock_z: Union[Unset, "LockZ"] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        ci: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.ci, Unset):
            ci = self.ci.to_dict()

        wf: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.wf, Unset):
            wf = self.wf.to_dict()

        wf_z: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.wf_z, Unset):
            wf_z = self.wf_z.to_dict()

        unlock_z: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.unlock_z, Unset):
            unlock_z = self.unlock_z.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if ci is not UNSET:
            field_dict["ci"] = ci
        if wf is not UNSET:
            field_dict["wf"] = wf
        if wf_z is not UNSET:
            field_dict["wfZ"] = wf_z
        if unlock_z is not UNSET:
            field_dict["unlockZ"] = unlock_z

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.client_info import ClientInfo
        from ..models.lock_z import LockZ
        from ..models.wf_diagram import WFDiagram
        from ..models.wf_diagram_z import WFDiagramZ

        d = src_dict.copy()
        _ci = d.pop("ci", UNSET)
        ci: Union[Unset, ClientInfo]
        if isinstance(_ci, Unset):
            ci = UNSET
        else:
            ci = ClientInfo.from_dict(_ci)

        _wf = d.pop("wf", UNSET)
        wf: Union[Unset, WFDiagram]
        if isinstance(_wf, Unset):
            wf = UNSET
        else:
            wf = WFDiagram.from_dict(_wf)

        _wf_z = d.pop("wfZ", UNSET)
        wf_z: Union[Unset, WFDiagramZ]
        if isinstance(_wf_z, Unset):
            wf_z = UNSET
        else:
            wf_z = WFDiagramZ.from_dict(_wf_z)

        _unlock_z = d.pop("unlockZ", UNSET)
        unlock_z: Union[Unset, LockZ]
        if isinstance(_unlock_z, Unset):
            unlock_z = UNSET
        else:
            unlock_z = LockZ.from_dict(_unlock_z)

        b_request_ix_service_port_if_checkin_workflow_template = cls(
            ci=ci,
            wf=wf,
            wf_z=wf_z,
            unlock_z=unlock_z,
        )

        b_request_ix_service_port_if_checkin_workflow_template.additional_properties = d
        return b_request_ix_service_port_if_checkin_workflow_template

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> elo_indexserver_client-0.1.30.tar.gz: elo_indexserver_client-0.1.30/eloclient/models/b_request_ix_service_port_if_checkin_workflow_template.py <==
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.client_info import ClientInfo
    from ..models.lock_z import LockZ
    from ..models.wf_diagram import WFDiagram
    from ..models.wf_diagram_z import WFDiagramZ


T = TypeVar("T", bound="BRequestIXServicePortIFCheckinWorkflowTemplate")


@_attrs_define
class BRequestIXServicePortIFCheckinWorkflowTemplate:
    """
    Attributes:
        unlock_z (Union[Unset, LockZ]): This class encapsulates the constants of the LockC class.
            <p>
             Copyright: Copyright (c) 2004
             </p>
             <p>
             Organisation: ELO Digital Office GmbH
             </p>
        ci (Union[Unset, ClientInfo]): Contains the session ticket and the users language and country.
            Each Indexserver interface
             function, except the login, requires a <code>ClientInfo</code> object as parameter with a valid
             session ticket.
             <p>
             Copyright: Copyright (c) 2004
             </p>
             <p>
             Organisation: ELO Digital Office GmbH
             </p>
        wf_z (Union[Unset, WFDiagramZ]): This class encapsulates the constants of the WFDiagramC class.
            <p>
             Copyright: Copyright (c) 2004
             </p>
             <p>
             Organisation: ELO Digital Office GmbH
             </p>
        wf (Union[Unset, WFDiagram]): This class represents an active or finished workflow or a workflow template
    """

    unlock_z: Union[Unset, "LockZ"] = UNSET
    ci: Union[Unset, "ClientInfo"] = UNSET
    wf_z: Union[Unset, "WFDiagramZ"] = UNSET
    wf: Union[Unset, "WFDiagram"] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        unlock_z: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.unlock_z, Unset):
            unlock_z = self.unlock_z.to_dict()

        ci: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.ci, Unset):
            ci = self.ci.to_dict()

        wf_z: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.wf_z, Unset):
            wf_z = self.wf_z.to_dict()

        wf: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.wf, Unset):
            wf = self.wf.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if unlock_z is not UNSET:
            field_dict["unlockZ"] = unlock_z
        if ci is not UNSET:
            field_dict["ci"] = ci
        if wf_z is not UNSET:
            field_dict["wfZ"] = wf_z
        if wf is not UNSET:
            field_dict["wf"] = wf

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.client_info import ClientInfo
        from ..models.lock_z import LockZ
        from ..models.wf_diagram import WFDiagram
        from ..models.wf_diagram_z import WFDiagramZ

        d = src_dict.copy()
        _unlock_z = d.pop("unlockZ", UNSET)
        unlock_z: Union[Unset, LockZ]
        if isinstance(_unlock_z, Unset):
            unlock_z = UNSET
        else:
            unlock_z = LockZ.from_dict(_unlock_z)

        _ci = d.pop("ci", UNSET)
        ci: Union[Unset, ClientInfo]
        if isinstance(_ci, Unset):
            ci = UNSET
        else:
            ci = ClientInfo.from_dict(_ci)

        _wf_z = d.pop("wfZ", UNSET)
        wf_z: Union[Unset, WFDiagramZ]
        if isinstance(_wf_z, Unset):
            wf_z = UNSET
        else:
            wf_z = WFDiagramZ.from_dict(_wf_z)

        _wf = d.pop("wf", UNSET)
        wf: Union[Unset, WFDiagram]
        if isinstance(_wf, Unset):
            wf = UNSET
        else:
            wf = WFDiagram.from_dict(_wf)

        b_request_ix_service_port_if_checkin_workflow_template = cls(
            unlock_z=unlock_z,
            ci=ci,
            wf_z=wf_z,
            wf=wf,
        )

        b_request_ix_service_port_if_checkin_workflow_template.additional_properties = d
        return b_request_ix_service_port_if_checkin_workflow_template

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
